# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define _with_repolib 1

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'
%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define version_maj  1
%define version_min  2
%define version_rev  09
%define version_tag %{version_maj}.%{version_min}_%{version_rev}
%define version_full %{version_tag}

Summary:        GlassFish JSF
Name:           glassfish-jsf
Version:        %{version_tag}
Release:        1%{?dist}
Epoch:          0
License:        CDDL
Group:          Development/Java
URL:            https://javaserverfaces.dev.java.net/
# https://javaserverfaces.dev.java.net/files/documents/1866/104152/mojarra-1.2_09-b02-FCS-source.zip
Source0:        %{name}-%{version}.zip
# FIXME: Get rid of these prebuilt binaries
# http://download.java.net/javaee5/external/shared/com-sun-commons-beanutils/jars/com-sun-commons-beanutils-1.6.1.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-collections/jars/com-sun-commons-collections-2.1.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-digester/jars/com-sun-commons-digester-1.5.jar
# http://download.java.net/javaee5/external/shared/com-sun-commons-logging/jars/com-sun-commons-logging-1.0.4.jar
# http://repository.codehaus.org/org/codehaus/groovy/groovy-all/1.5.5/groovy-all-1.5.5.jar
Source1:        %{name}-%{version}-deps.tar.gz
Source2:        %{name}-%{version}-build.xml
Source3:        %{name}-%{version}-impl-overlay.jar
# This is derived from the contents of this zip:
# https://javaserverfaces.dev.java.net/files/documents/1866/104151/mojarra-1.2_09-b02-FCS-binary.zip
# The files in the jar are those selected by the following command:
# find -type f '!' -iname *.class '!' -wholename '*com/sun/org/apache*'
# This is necessary to replicate Sun's binary distribution as closely as possible
# and is applied in the build.xml
Source4:        %{name}-%{version}-component-info.xml
BuildRequires:  ant
BuildRequires:  servletapi6
BuildRequires:  glassfish-jstl
BuildRequires:  jbossweb
BuildRequires:  apache-portlet-1.0-api
BuildRequires:  jpackage-utils
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The JSF 1.2 implementation. NB: We've omitted the classes
Jetty6InjectionProvider and GlassFishInjectionProvider from the
package com.sun.faces.vendor.


%define repodir %{_javadir}/repository.jboss.com/glassfish/jsf/%{version_full}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %{with_repolib}
%package repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	         Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
# Unroll the sources into a clean heirarchy for our ant buildfile
mkdir -p together/{api,impl,tools,deps}/{src,build}

unzip -qq %{SOURCE0}
cp -R mojarra-1.2_09-b02-FCS-sources/jsf-api/src/* \
      mojarra-1.2_09-b02-FCS-sources/jsf-api/build/generate/* together/api/src
cp -R mojarra-1.2_09-b02-FCS-sources/jsf-ri/src/* \
      mojarra-1.2_09-b02-FCS-sources/jsf-ri/build/generate/* together/impl/src
cp -R mojarra-1.2_09-b02-FCS-sources/jsf-tools/src/* together/tools/src

# FIXME: Get rid of these prebuilt binaries
pushd together/deps
  tar xf %{SOURCE1}
  jar xf com-sun-commons-logging-1.0.4.jar
  rm -f com-sun-commons-logging-1.0.4.jar
  jar xvf com-sun-commons-beanutils-1.6.1.jar
  rm -f com-sun-commons-beanutils-1.6.1.jar
  jar xvf com-sun-commons-digester-1.5.jar
  rm -f com-sun-commons-digester-1.5.jar
  jar xvf com-sun-commons-collections-2.1.jar
  rm -f com-sun-commons-collections-2.1.jar
  deppath=$(build-classpath-directory $(pwd))
popd

pushd together
  cp -p %{SOURCE2} ./build.xml
  sed -i "s|@DEP-PATH@|$deppath|g;" build.xml
  sed -i "s|@BASE-DIR@|`pwd`|g;" build.xml
  s3=%{SOURCE3}
  sed -i "s|@IMPL-OVERLAY@|$s3|g;" build.xml
  sed -i "s|@MF-SPEC-TITLE@|JavaServer Faces|g;" build.xml
  sed -i "s|@MF-SPEC-VERSION@|1.2MR1|g;" build.xml
  sed -i "s|@MF-IMPL-TITLE@|Sun Microsystems JavaServer Faces Implementation|g;" build.xml
  implversion=%{version_full}-b02-FCS
  sed -i "s|@MF-IMPL-VERSION@|$implversion|g;" build.xml

  # These injection providers are too much trouble to build (and not useful to JBoss)
  rm -f impl/src/com/sun/faces/vendor/{GlassFish,Jetty6}InjectionProvider.java
popd

%build
pushd together
  export CLASSPATH=
  export OPT_JAR_LIST=:
  ant jar
popd

%install
rm -rf $RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/
install -p -m 0644 together/api/build/jsf-api.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-api-%{version_full}.jar
install -p -m 0644 together/impl/build/jsf-impl.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-impl-%{version_full}.jar

pushd $RPM_BUILD_ROOT%{_javadir}
    ln -sf %{name}-api-%{version_full}.jar  %{name}-api.jar
    ln -sf %{name}-impl-%{version_full}.jar %{name}-impl.jar
    
    ln -sf %{name}-api-%{version_full}.jar  jsf-api.jar
    ln -sf %{name}-impl-%{version_full}.jar jsf-impl.jar
popd

%if %{with_repolib}
    install -d -m 755 $RPM_BUILD_ROOT%{repodir}
    install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
    install -p -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{repodir}/component-info.xml
    tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
    sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
    sed -i s/@VERSION@/%{version_full}-brew/g $RPM_BUILD_ROOT%{repodir}/component-info.xml
    install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
    install -p -m 644 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
    install -p -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{repodirsrc}
    install -p -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{repodirsrc}
    install -p -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{repodirsrc}
    cp -p --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-api.jar $RPM_BUILD_ROOT%{repodirlib}
    cp -p --dereference $RPM_BUILD_ROOT%{_javadir}/jsf-impl.jar $RPM_BUILD_ROOT%{repodirlib}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(0644,root,root,0755)
%{_javadir}/jsf-api.jar
%{_javadir}/%{name}-api.jar
%{_javadir}/%{name}-api-%{version_full}.jar
%{_javadir}/jsf-impl.jar
%{_javadir}/%{name}-impl.jar
%{_javadir}/%{name}-impl-%{version_full}.jar

%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Mon Aug 11 2008 David Walluck <dwalluck@redhat.com> 0:1.2_09-1
- 1.2_09

* Fri Jul 18 2008 David Walluck <dwalluck@redhat.com> 0:1.2_08-3
- fix version by setting %%{version_post}
- fix unpacking of sources
- fix repolib permissions

* Fri Jul 11 2008 David Walluck <dwalluck@redhat.com> 0:1.2_08-2
- use excalibur for avalon

* Thu Jun 12 2008 Permaine Cheung <pcheung@redhat.com> 0:1.2_08-1
- First JPP 5 build

* Thu Apr 24 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_08-0jpp.ep1.3
- Output JARs now have proper MANIFEST.MFs

* Wed Mar 19 2008 Jon Prindiville <jprindiv@redhat.com> 0:1.2_08-0jpp.ep1.1
- Upgrading to 1.2_08

* Fri Nov 30 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.18
- Adding a bunch of Apache commons source to compile in with the -impl stuff

* Thu Nov 29 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.17
- Adding an "overlay" JAR containing all of the non-classfiles which our -impl
  JAR is missing when compared to Sun's (see also, note at Source1)
- Adding the overlay jar and -build.xml to %%{repodirsrc}

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.16
- Adding jbossweb's annotations-api.jar to the impl's classpath

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.15
- Fixing mistakely clobbered @API-DIR@ and @IMPL-DIR@ targets in -build.xml

* Wed Nov 28 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.14
- First complete build

* Fri Nov 23 2007 Fernando Nasser <fnasser@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.13
- Revert to sun-jaf name to please buildmagic

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.12
- Added -brew suffix.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-1.p02.0jpp.ep1.11
- %%{release} twiddling (to appease the packaging gods)

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.11.p02
- Fixed build.xml path confusion.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.10.p02
- Brain not work good today. BuildRequiring ant.

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.9.p02
- Fixed 'make new-source's omission of the jsf-impl JAR from sources

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.8.p02
- Uploaded new (non-broken!) version of Source0

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.7.p02
- Corrected %%install section, and -impl's %%setup

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.6.p02
- Unbreaking the references to the ant buildfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.5.p02
- Using ant rather than inlining the build in the specfile

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.4.p02
- Changed -api's javac invocation

* Fri Nov 23 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.3.p02
- Added -api's sources to its classpath

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.2.p02
- Removed version specification from BR: glassfish-jstl

* Thu Nov 22 2007 Jon Prindiville <jprindiv@redhat.com> 0:1.2_04-0jpp.ep1.1.p02
- First release. The -api JAR is building, the -impl JAR is not (yet).
